import { Utilities } from '@/util/Utilities';
import {
  Button,
  DialogService,
  Form, LoadingService, Modal, ModalService, Select, Tabs, TextInput,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmConcorrenteController {
  private modalAdicionar!: Modal;

  public visibilidade: boolean = true;

  public currentRow: any = {};

  get visibilidadeDoFrame() {
    return !this.visibilidade;
  }

  public voltarPaginaInicial() {
    this.visibilidade = true;
  }

  public closeModal() {
    this.modalAdicionar.hide();
    this.modalAdicionar?.destroy();
  }

  public visualizarDadosGerais({ row }: any) {
    this.visibilidade = false;
    this.currentRow = row;
    this.recarregarTabs();
  }

  public recarregarTabs(): void {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-competition');
    if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-general-data') {
      this.montarInformacoesDadosGerais();
    }
  }

  public montarInformacoesDadosGerais() {
    Metadata.getInstance<TextInput>('NRCONCORRENTE').value = this.currentRow.NRCONCORRENTE;
    Metadata.getInstance<TextInput>('NRINSCRICAOCONC').value = this.currentRow.NRINSCRICAOCONC;
    Metadata.getInstance<TextInput>('CDTIPOINSCRICAO').value = this.currentRow.CDTIPOINSCRICAO;
    Metadata.getInstance<TextInput>('NMRAZSOCCONC').value = this.currentRow.NMRAZSOCCONC;
    Metadata.getInstance<Select>('IDATIVO').value = this.currentRow.IDATIVO;
    Metadata.getInstance<TextInput>('NMFANTCONN').value = this.currentRow.NMFANTCONN;
    Metadata.getInstance<TextInput>('NRCEPCONC').value = this.currentRow.NRCEPCONC;
    Metadata.getInstance<TextInput>('DSENDERECOCONC').value = this.currentRow.DSENDERECOCONC;
    Metadata.getInstance<TextInput>('NRENDERECOCONC').value = this.currentRow.NRENDERECOCONC;
    Metadata.getInstance<TextInput>('DSCOMPLEENDECONC').value = this.currentRow.DSCOMPLEENDECONC;
    Metadata.getInstance<Select>('NMPAIS').value = this.currentRow.NMPAIS;
    Metadata.getInstance<TextInput>('NMPAIS').value = this.currentRow.CDPAIS;
    Metadata.getInstance<TextInput>('SGESTADO').value = this.currentRow.SGESTADO;
    Metadata.getInstance<Select>('SGESTADO').value = this.currentRow.NMESTADO;
    Metadata.getInstance<Select>('NMMUNICIPIO').value = this.currentRow.NMMUNICIPIO;
    Metadata.getInstance<TextInput>('NMMUNICIPIO').value = this.currentRow.CDMUNICIPIO;
    Metadata.getInstance<Select>('NMBAIRRO').value = this.currentRow.NMBAIRRO;
    Metadata.getInstance<TextInput>('NMBAIRRO').value = this.currentRow.CDBAIRRO;
    Metadata.getInstance<TextInput>('NRTELCONC').value = this.currentRow.NRTELCONC;
    Metadata.getInstance<TextInput>('DSEMAILCONC').value = this.currentRow.DSEMAILCONC;
    Metadata.getInstance<TextInput>('DSHOMEPAGECONC').value = this.currentRow.DSHOMEPAGECONC;
    Metadata.getInstance<TextInput>('DSOBSERVCONC').value = this.currentRow.DSOBSERVCONC;
  }

  public saveEditCompetition() {
    LoadingService.show();
    const grid = Metadata.getInstance<TekGrid>('tek-grid-crm_concorrente-grid');
    const params = {
      NRCONCORRENTE: Metadata.getInstance<Select>('NRCONCORRENTE').value,
      NRINSCRICAOCONC: Metadata.getInstance<Select>('NRINSCRICAOCONC').value,
      CDTIPOINSCRICAO: Metadata.getInstance<Select>('CDTIPOINSCRICAO').value,
      NMRAZSOCCONC: Metadata.getInstance<Select>('NMRAZSOCCONC').value,
      IDATIVO: Metadata.getInstance<Select>('IDATIVO').value,
      NMFANTCONN: Metadata.getInstance<Select>('NMFANTCONN').value,
      CEP: Metadata.getInstance<Select>('NRCEPCONC').value,
      DSENDERECOCONC: Metadata.getInstance<Select>('DSENDERECOCONC').value,
      NRENDERECOCONC: Metadata.getInstance<Select>('NRENDERECOCONC').value,
      DSCOMPLEENDECONC: Metadata.getInstance<Select>('DSCOMPLEENDECONC').value,
      NMPAIS: Metadata.getInstance<Select>('NMPAIS').selectValue.NMPAIS,
      CDPAIS: Metadata.getInstance<Select>('NMPAIS').value,
      SGESTADO: Metadata.getInstance<Select>('SGESTADO').value,
      NMESTADO: Metadata.getInstance<Select>('SGESTADO').selectValue.NMESTADO,
      NMMUNICIPIO: Metadata.getInstance<Select>('NMMUNICIPIO').selectValue.NMMUNICIPIO,
      CDMUNICIPIO: Metadata.getInstance<Select>('NMMUNICIPIO').value,
      NMBAIRRO: Metadata.getInstance<Select>('NMBAIRRO').selectValue.NMBAIRRO,
      CDBAIRRO: Metadata.getInstance<Select>('NMBAIRRO').value,
      NRTELCONC: Metadata.getInstance<Select>('NRTELCONC').value,
      DSEMAILCONC: Metadata.getInstance<Select>('DSEMAILCONC').value,
      DSHOMEPAGECONC: Metadata.getInstance<Select>('DSHOMEPAGECONC').value,
      DSOBSERVCONC: Metadata.getInstance<Select>('DSOBSERVCONC').value,
    };
    Http.post('/updateCompetition', params).then(() => {
      this.recarregarTabs();
      grid.reload();
      this.voltarPaginaInicial();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public async openModalNewCompetition() {
    this.modalAdicionar = await ModalService.createFromJson('crm_concorrente/Modal/modal_new_competition', true);
    await this.modalAdicionar.show();
  }

  public clickButtonToExpand({ component }: any) {
    const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
    form.isVisible = !form.isVisible;

    component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
  }

  public saveNewCompetition() {
    const formModalInscription = Metadata.getInstance<Form>('form_inscription');
    const formModalAddress = Metadata.getInstance<Form>('formAddress');
    const formModalAdditionalData = Metadata.getInstance<Form>('formAdditionalData');
    const grid = Metadata.getInstance<TekGrid>('tek-grid-crm_concorrente-grid');
    const params = {
      NRCONCORRENTE: Metadata.getInstance<Select>('NRCONCORRENTE-MODAL').value,
      NRINSCRICAOCONC: Metadata.getInstance<Select>('NRINSCRICAOCONC-MODAL').value,
      CDTIPOINSCRICAO: Metadata.getInstance<Select>('CDTIPOINSCRICAO-MODAL').value,
      NMRAZSOCCONC: Metadata.getInstance<Select>('NMRAZSOCCONC-MODAL').value,
      IDATIVO: Metadata.getInstance<Select>('IDATIVO-MODAL').value,
      NMFANTCONN: Metadata.getInstance<Select>('NMFANTCONN-MODAL').value,
      CEP: Metadata.getInstance<Select>('NRCEPCONC-MODAL').value,
      DSENDERECOCONC: Metadata.getInstance<Select>('DSENDERECOCONC-MODAL').value,
      NRENDERECOCONC: Metadata.getInstance<Select>('NRENDERECOCONC-MODAL').value,
      DSCOMPLEENDECONC: Metadata.getInstance<Select>('DSCOMPLEENDECONC-MODAL').value,
      NMPAIS: Metadata.getInstance<Select>('MODAL_NMPAIS').selectValue.NMPAIS,
      CDPAIS: Metadata.getInstance<Select>('MODAL_NMPAIS').value,
      SGESTADO: Metadata.getInstance<Select>('MODAL_SGESTADO').value,
      NMESTADO: Metadata.getInstance<Select>('MODAL_SGESTADO').selectValue.NMESTADO,
      NMMUNICIPIO: Metadata.getInstance<Select>('MODAL_NMMUNICIPIO').selectValue.NMMUNICIPIO,
      CDMUNICIPIO: Metadata.getInstance<Select>('MODAL_NMMUNICIPIO').value,
      NMBAIRRO: Metadata.getInstance<Select>('MODAL_NMBAIRRO').selectValue.NMBAIRRO,
      CDBAIRRO: Metadata.getInstance<Select>('MODAL_NMBAIRRO').value,
      NRTELCONC: Metadata.getInstance<Select>('NRTELCONC-MODAL').value,
      DSEMAILCONC: Metadata.getInstance<Select>('DSEMAILCONC-MODAL').value,
      DSHOMEPAGECONC: Metadata.getInstance<Select>('DSHOMEPAGECONC-MODAL').value,
      DSOBSERVCONC: Metadata.getInstance<Select>('DSOBSERVCONC-MODAL').value,
    };
    if (
      Utilities.validateForm(formModalInscription)
      && Utilities.validateForm(formModalAddress)
      && Utilities.validateForm(formModalAdditionalData)
    ) {
      LoadingService.show();
      Http.post('/saveNewCompetition', params).then(() => {
        grid.datasource.get();
        this.closeModal();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }

  public messageDeleteCompetition({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmConcorrenteController.deleteCompetition');
  }

  public deleteCompetition() {
    const component = Metadata.getInstance<TekGrid>('tek-grid-crm_concorrente-grid');
    LoadingService.show();
    Http.post('/deleteCompetition', {
      NRCONCORRENTE: component.selectedRows.map((element: any) => element.NRCONCORRENTE),
    }).then(() => {
      Utilities.showSuccessMessage();
      component.datasource.get();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      component.selectedRows = [];
      LoadingService.hide();
      DialogService.hide();
    });
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }
}
